@@ -32,7 +32,7 @@ use overload
     'atan2' => \&_overload_atan2,
 ;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 DynaLoader::bootstrap Math::Complex_C::L $VERSION;
 
@@ -220,6 +220,15 @@ Math::Complex_C::L - perl interface to C's long double complex operations.
    section of the README that ships with this module's source for a more
    detailed explanation.
 
+   A number of the functions below accept string arguments. These arguments
+   will be tested by the perl API function looks_like_number() for the
+   presence of non-numeric characters. If any such non-numeric characters
+   are detected, then the global non-numeric flag (which is initially set to
+   0) will be incremented. You can query the value this global flag holds by
+   running Math::Complex_C::L::nnumflag() and you can manually alter the
+   value of the global using Math::Complex_C::L::set_nnum and
+   Math::Complex_C::L::clear_nnum. These functions are documented below.
+
 =head1 FUNCTIONS
 
    $rop = Math::Complex_C::L->new($re, $im);
@@ -423,9 +432,13 @@ Math::Complex_C::L - perl interface to C's long double complex operations.
 
 =head1 OUTPUT FUNCTIONS
 
-   Default precision for output of Math::Complex_C::L objects is whatever is
-   specified by the macro LDBL_DIG in float.h (usually 18). If LDBL_DIG
-   is not defined then default precision is set to 18 decimal digits.
+   Default precision for output of Math::Complex_C::L objects is set
+   in the XS global _MATH_COMPLEX_C_L_DIGITS to
+        1 + ceil(MANT_PREC * log(2) / log(10)
+    where MANT_PREC is LDBL_MANT_DIG if float.h defines that symbol.
+    Else MANT_PREC is DBL_MANT_DIG if float.h defines that symbol.
+    Else MANT_PREC is 21 (which is the correct value for a 64-bit
+    precision mantissa).
 
    This default can be altered using l_set_prec (see below).
 
@@ -483,12 +496,29 @@ Math::Complex_C::L - perl interface to C's long double complex operations.
     (A "true" Math::Complex_C object is, of course, simply one
     that is not "false".)
 
+=head1 OTHER FUNCTIONS
+
+    $iv = Math::Complex_C::L::nnumflag(); # not exported
+     Returns the value of the non-numeric flag. This flag is
+     initialized to zero, but incemented by 1 whenever a function
+     is handed a string containing non-numeric characters. The
+     value of the flag therefore tells us how many times functions
+     have been handed such a string. The flag can be reset to 0 by
+     running clear_nnum().
+
+    Math::Complex_C::L::set_nnum($iv); # not exported
+     Resets the global non-numeric flag to the value specified by
+     $iv.
+
+    Math::Complex_C::L::clear_nnum(); # not exported
+     Resets the global non-numeric flag to 0.(Essentially the same
+     as running set_nnum(0).)
 
 =head1 LICENSE
 
    This module is free software; you may redistribute it and/or modify it under
    the same terms as Perl itself.
-   Copyright 2014, Sisyphus.
+   Copyright 2014, 2016, Sisyphus.
 
 =head1 AUTHOR
 
